@@ -393,7 +393,7 @@ local function resolveLongString(finishMark)
         finishOffset = #Lua + 1
         miss = true
     end
-    local stringResult = start and ssub(Lua, start, finishOffset - 1)
+    local stringResult = start and ssub(Lua, start, finishOffset - 1) or ''
     local lastLN = stringResult:find '[\r\n][^\r\n]*$'
     if lastLN then
         local result = stringResult
@@ -606,6 +606,14 @@ local function parseLocalAttrs()
             attr[1] = word
             attr.finish = wfinish
             Index = Index + 2
+            if  word ~= 'const'
+            and word ~= 'close' then
+                pushError {
+                    type   = 'UNKNOWN_ATTRIBUTE',
+                    start  = wstart,
+                    finish = wfinish,
+                }
+            end
         else
             missName()
         end
@@ -1631,6 +1639,30 @@ local function parseTable()
     return tbl
 end
 
+local function addDummySelf(node, call)
+    if node.type ~= 'getmethod' then
+        return
+    end
+    -- dummy param `self`
+    if not call.args then
+        call.args = {
+            type   = 'callargs',
+            start  = call.start,
+            finish = call.finish,
+            parent = call,
+        }
+    end
+    local newNode = {}
+    for k, v in next, call.node.node do
+        newNode[k] = v
+    end
+    newNode.mirror = call.node.node
+    newNode.dummy  = true
+    newNode.parent = call.args
+    call.node.node.mirror = newNode
+    tinsert(call.args, 1, newNode)
+end
+
 local function parseSimple(node, funcName)
     local lastMethod
     while true do
@@ -1732,26 +1764,7 @@ local function parseSimple(node, funcName)
                 args.parent = call
                 call.args   = args
             end
-            if node.type == 'getmethod' then
-                -- dummy param `self`
-                if not call.args then
-                    call.args = {
-                        type   = 'callargs',
-                        start  = call.start,
-                        finish = call.finish,
-                        parent = call,
-                    }
-                end
-                local newNode = {}
-                for k, v in next, call.node.node do
-                    newNode[k] = v
-                end
-                newNode.mirror = call.node.node
-                newNode.dummy  = true
-                newNode.parent = call.args
-                call.node.node.mirror = newNode
-                tinsert(call.args, 1, newNode)
-            end
+            addDummySelf(node, call)
             node.parent = call
             node = call
         elseif token == '{' then
@@ -1773,6 +1786,7 @@ local function parseSimple(node, funcName)
                 [1]    = tbl,
             }
             call.args   = args
+            addDummySelf(node, call)
             tbl.parent  = args
             node.parent = call
             node        = call
@@ -1795,6 +1809,7 @@ local function parseSimple(node, funcName)
                 [1]    = str,
             }
             call.args   = args
+            addDummySelf(node, call)
             str.parent  = args
             node.parent = call
             node        = call
@@ -1818,6 +1833,7 @@ local function parseSimple(node, funcName)
                     [1]    = str,
                 }
                 call.args   = args
+                addDummySelf(node, call)
                 str.parent  = args
                 node.parent = call
                 node        = call
